/*
 * LCD.c
 *
 *  Created on: Jun 26, 2015
 *      Author: RK
 */
#include <SI_EFM8UB1_Register_Enums.h>		// SFR declarations
#include "SPI_Test_Defs.h"


//Global variables
unsigned char LCDModeSelect;
unsigned char LCDLineAddress;
unsigned char LCDLineData[LINE_NUM_BYTES];
unsigned char LCDTxState;




///////////////////////////////////////////////////////////////////////////////////////

void InitLCD()
{
	SPI_CS = LOW;															//make sure that the chip select signal is LOW

	LCDAllClear();																//first clear the LCD to all white pixels

	//the last two bytes of line data, which are dummy bytes, should always be filled with zeros
	LCDLineData[LINE_NUM_BYTES-2] = 0x00;
	LCDLineData[LINE_NUM_BYTES-1] = 0x00;
}

void Fill_LineData_White()
{
	unsigned char n;

	for (n = 0; n < LINE_NUM_BYTES-2; n++)
	{
		LCDLineData[n] = 0xFF;
	}
}

void Fill_LineData_Black()
{
	unsigned char n;

	for (n = 0; n < LINE_NUM_BYTES-2; n++)
	{
		LCDLineData[n] = 0x00;
	}
}

void WriteLCDLine(unsigned char LineAddress)
{
	SPI_CS = HIGH;																//set chip select HIGH to enable data transfer to the LCD

	SFRPAGE = TIMER4_PAGE; TMR4L = 0; while(TMR4L < 30);				//this ensures adequate delay from driving chip select high to the start of data transfer (tsSCS in the LCD data sheet)

	LCDTxState = SING_LINE_WRITEMODE_SENT;								//this tells the ISR to send the address byte after this mode select byte is sent

	LCDLineAddress = LineAddress;											//fill the address variable with the address passed to the function

	SFRPAGE = SPI0_PAGE;
	SPI0DAT = 0x00 | BIT7;														//this initiates transfer of the first byte (the mode select byte)
																										// 0x00 | BIT7 corresponds to "data update mode"

	/*when transfer of this byte is complete, the SPI interrupt will fire, and the rest
	of the transfer is handled in the ISR*/
}


void LCDAllClear()
{
	SPI_CS = HIGH;																//Set chip select HIGH to enable data transfer to the LCD

	SFRPAGE = TIMER4_PAGE; TMR4L = 0; while(TMR4L < 30);			//this ensures adequate delay from driving chip select high to the start of data transfer (tsSCS in the LCD data sheet)

	LCDTxState = ALL_CLEAR_SENT;										//this tells the ISR that this transfer sequence is an all clear command, not a transmission of pixel data

	SFRPAGE = SPI0_PAGE;
	SPI0DAT = 0x00 | BIT5;														//this initiates transfer of the first byte (the mode select byte)
																										// 0x00 | BIT5 corresponds to "all clear mode"

	/*when transfer of this byte is complete, the SPI interrupt will fire, and the rest
	of the transfer is handled in the ISR*/
}


