
//-----------------------------------------------------------------------------
// Includes
//-----------------------------------------------------------------------------
#include <SI_EFM8UB1_Register_Enums.h>                  // SFR declarations
#include "InitDevice.h"
#include "SPI_Test_Defs.h"

//variables
bit CLEAR_PREV_LINE = 0;
unsigned char Scroll_LineNum = 0;

//-----------------------------------------------------------------------------
// main() Routine
// ----------------------------------------------------------------------------
int main (void)
{
	// Call hardware initialization routine
	enter_DefaultMode_from_RESET();

	InitLCD();										//clear the LCD screen to all white and initialize variables used in the LCD interface

	SFRPAGE = TIMER2_PAGE;
	TMR2CN0_TR2 = 1;							//start Timer2, which is used to schedule write events that create the line scrolling effect

	while (1) 
   {
		if(SEND_NEXT_LINE_FLAG)					//this flag is set in the Timer2 ISR
		{
			SEND_NEXT_LINE_FLAG = 0;

			//first the line is written to black, then for the next frame that same line is cleared to white
			//the CLEAR_PREV_LINE flag is used to keep track of which task is performed next: clearing the previous line or writing black to the new line
			if(CLEAR_PREV_LINE)
			{
				CLEAR_PREV_LINE = 0;
				Fill_LineData_White();																//fill the LCD data array with all ones, corresponding to all white
				WriteLCDLine(LCDLineAddr_LUT[Scroll_LineNum]);		//then write the line data
				if(Scroll_LineNum == LCD_NUM_LINES)								//once the final line is cleared, the scrolling effect continues by starting again with the first line
					Scroll_LineNum = 0;
				else
					Scroll_LineNum++;
			}

			else
			{
				CLEAR_PREV_LINE = 1;
				Fill_LineData_Black();																//fill the LCD data array with all zeros, corresponding to all black
				WriteLCDLine(LCDLineAddr_LUT[Scroll_LineNum]);		//then write the line data
			}
		}
   }
}


